==> haskell-expiring-cache-map-0.0.6.1-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-IF3VVuElLhl9sB1xtPU3sp
key: expiring-cache-map-0.0.6.1-IF3VVuElLhl9sB1xtPU3sp
license: BSD-3-Clause
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
author: Edward L. Blake
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
abi: 8f0d6599d605275222002dd5ec16a5b8
exposed: True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-IF3VVuElLhl9sB1xtPU3sp
depends:
    base-4.11.1.0 containers-0.5.11.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-expiring-cache-map-0.0.6.1-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-1zdAQcbI1vnLTWaAGqCbW7
key: expiring-cache-map-0.0.6.1-1zdAQcbI1vnLTWaAGqCbW7
license: BSD-3-Clause
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
author: Edward L. Blake
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
abi: fdcb272eea9c7fb07f633e0cacc88df7
exposed: True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-1zdAQcbI1vnLTWaAGqCbW7
depends:
    base-4.11.1.0 containers-0.5.11.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
